<?php
namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;
use Teknisa\CNC\Services;
use Teknisa\CNC\Utilities;

class Cnc00100Criterio extends \Teknisa\CNC\Controllers\TeknisaCrud {
    
    protected $dataSourceManager;
    protected $crudService;
    protected $criterioService;
    protected $salesMessage;
    
    public function __construct($dataSourceManager, $crudService, Services\Cnc00100Criterio $criterioService, Utilities\SalesMessageCNC $salesMessage) {
        $this->dataSourceManager  = $dataSourceManager;
        $this->crudService        = $crudService;
        $this->criterioService    = $criterioService;
        $this->salesMessage       = $salesMessage;
    }
    
    public function findCriterio(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->findCriterio($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaCriterioRepo', $criterioestabelec));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function findCriterioEst(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->findCriterioEst($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaCriteriosEstabelecRepo', $criterioestabelec));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function findCriterioOrder(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->findCriterioOrder($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensRepo', $criterioestabelec));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function findCriterioOrderEst(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->findCriterioOrderEst($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensEstRepo', $criterioestabelec));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function findCriterioOrderCad(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->findCriterioOrderCad($params);
            if(count($criterioestabelec) == 0){
                $criterioestabelec = array(
			        'NRADQUIRENTE'     => $params[0]['value']
		        );
            }
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensCadRepo', $criterioestabelec));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function findCriterioOrderCadEst(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->findCriterioOrderEstCad($params);
            if(count($criterioestabelec) == 0){
                $criterioestabelec = array(
			        'NRADQUIRENTE'     => $params[0]['value'],
			        'NRESTABELEC'      => $params[1]['value']
		        );
            }
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensEstCadRepo', $criterioestabelec));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function saveCriterioOrder(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            if($row[0]["__is_new"] == true){
                $this->criterioService->insertOrderStandarts($row);
                $message= array($this->salesMessage->getMessage('alterado'));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensRepo', $message));
            } else {
                $criterioestabelec = $this->criterioService->updateOrderStandarts($row);
                $message= array($this->salesMessage->getMessage('alterado'));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensRepo', $message));
            }

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveCriterioOrderEst(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            
            if($row[0]["__is_new"] == true){
                $this->criterioService->insertOrderStandartsEst($row);
                $message= array($this->salesMessage->getMessage('alterado'));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensEstRepo', $message));
            } else {
                $criterioestabelec = $this->criterioService->updateOrderStandartsEst($row);
                $message= array($this->salesMessage->getMessage('alterado'));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaOrdensEstRepo', $message));
            }

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function removeCriterio(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            $this->criterioService->clearOrderStandarts($row);
            
            $message= array($this->salesMessage->getMessage('alterado'));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaCriterioRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function removeCriterioOrderEst(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            $this->criterioService->clearOrderStandartsEst($row);
            
            $message= array($this->salesMessage->getMessage('alterado'));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaCriterioRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function saveCriterio(DTO\Request $request, DTO\Response $response){
        try {
            $row = $request->getDataSet()->getRows();

            $this->criterioService->alterarCriterio($row);

            $message= array($this->salesMessage->getMessage('alterado'));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_AlteraCriterioRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function updateEstabelecStandarts(Request\Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->updateEstabelecStandarts($params);
            
            $message= array($this->salesMessage->getMessage('alterado'));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_AlteraCriteriosEstabelecRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function saveCriterioEst(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            if($row[0]["__is_new"] == true){
                $this->criterioService->insertEstabelecStandarts($row);
                $message= array($this->salesMessage->getMessage('alterado'));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_AdicionaCriteriosEstabelecRepo', $message));
            } else {
                $criterioestabelec = $this->criterioService->updateEstabelecStandarts($row);
                $message= array($this->salesMessage->getMessage('alterado'));
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_AlteraCriteriosEstabelecRepo', $message));
            }

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function deleteCriterioEst(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows();
            $this->criterioService->clearEstabelecStandarts($row);
            
            $message= array($this->salesMessage->getMessage('alterado'));
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_LimpaCriteriosEstAdqRepo', $message));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getEstabelecStandarts(Request\Filter $request, Response $response) {
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $criterioestabelec = $this->criterioService->getEstabelecStandarts($params);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('Cnc00100_BuscaCriteriosEstabelecRepo', $criterioestabelec));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

}