<?php

namespace Teknisa\CNC\Services;

use Teknisa\CNC\Utilities;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;

use Teknisa\Libs\Util\Environment;

use Teknisa\CNC\Utilities\UtilCNC;

use Teknisa\CNC\Factories\Cnc00300ProdutoAdquirenteFactory;

class Cnc00300ProdutoAdquirenteService {
    
    protected $entityManager;
    protected $factory;
    protected $util;
    protected $salesMessage;
    
    public function __construct(\Doctrine\ORM\EntityManager $entityManager, Cnc00300ProdutoAdquirenteFactory $factory, UtilCNC $util, Utilities\SalesMessageCNC $salesMessage,
                                $conn)  {
		$this->entityManager = $entityManager;
		$this->factory = $factory;
		$this->util = $util;
        $this->salesMessage  = $salesMessage;
        $this->conn = $conn;
	}
	
	public function getProdAdq($row){
		$acquires = $this->factory->getProdAdq(array(
			':NRORG' => $row['NRORG']
        ));
		return $acquires;
	}
	
    public function getProdutosGer ($params) {
        $NRORG = $params['NRORG'];
        $ficaFrioAi= null;
        if(isset($params[0])){
            if(is_array($params[0]['value'])){
                $ficaFrioAi= true;
                for ($i=0; $i < sizeof($params); $i++) {
                    if($params[$i]["columnName"] === 'LABELPRODUTOADQ' || $params[$i]["columnName"] === 'NMPRODUTOADQ'){
                        $LABELPRODUTOADQ = $params[$i]['value'];
                    }
                }
                $paramsfilial = array(
                    ':LABELPRODUTOADQ' => $LABELPRODUTOADQ
                );
                $query = "SELECT PR.NRPRODUTOADQ, PR.CDPRODUTOADQ, PR.NMPRODUTOADQ, PR.CDTIPORECE,  TR.NMTIPORECE, PR.VRTOLERANCIA, PR.IDATIVO, PR.NRORG, PR.NRBANDEIRAVAN, BAND.NMBANDEIRA, BAND.CDBANDEIRA, 'Sim' ATIVO, PR.IDVISIVEL FROM PRODUTOADQ PR LEFT JOIN BANDEIRAVAN BAND ON PR.NRBANDEIRAVAN = BAND.NRBANDEIRAVAN LEFT JOIN TIPORECE TR ON PR.CDTIPORECE = TR.CDTIPORECE WHERE PR.NRORG = :NRORG AND UPPER(PR.CDPRODUTOADQ|| ' - ' ||PR.NMPRODUTOADQ) LIKE UPPER(:LABELPRODUTOADQ) AND PR.IDVISIVEL = 'S' AND PR.IDATIVO = 'S' UNION SELECT PR.NRPRODUTOADQ, PR.CDPRODUTOADQ, PR.NMPRODUTOADQ, PR.CDTIPORECE, TR.NMTIPORECE, PR.VRTOLERANCIA, PR.IDATIVO, PR.NRORG, PR.NRBANDEIRAVAN, BAND.NMBANDEIRA, BAND.CDBANDEIRA, 'Não' ATIVO, PR.IDVISIVEL FROM PRODUTOADQ PR LEFT JOIN BANDEIRAVAN BAND ON PR.NRBANDEIRAVAN = BAND.NRBANDEIRAVAN LEFT JOIN TIPORECE TR ON PR.CDTIPORECE = TR.CDTIPORECE WHERE PR.NRORG = :NRORG AND UPPER(PR.CDPRODUTOADQ|| ' - ' ||PR.NMPRODUTOADQ) LIKE UPPER(:LABELPRODUTOADQ) AND PR.IDVISIVEL  = 'N' AND PR.IDATIVO = 'S' ORDER BY NMPRODUTOADQ"; 
                foreach (array_keys($paramsfilial) as $index => $name) {
                    if(!empty($paramsfilial[$name])){
                        $query = $this->util->putArrayOnQuery($query, $name, $paramsfilial[$name]);
                        $paramsfilial[$name] = '';
                    }
                    else{
                        $paramsfilial[$name] = 'null';
                    }
                }
                $query = preg_replace('/'.':NRORG'.'/', $NRORG, $query, 1);
                $resultadoFiltrado = $this->estabelecFactory->getEstabelecFiltered($query);
                return $resultadoFiltrado;
            }   
            for ($i=0; $i < sizeof($params); $i++) {
                if(isset($params[$i]["columnName"])){
                    if($params[$i]["columnName"] === 'NMPRODUTOADQ'){
                        $LABELPRODUTOADQ = $params[$i]['value'];
                    }
                    if($LABELPRODUTOADQ === ""){
                        $LABELPRODUTOADQ = "%%";
                    }
                }
            }
            $LABELPRODUTOADQ = $params[0]['value'];
        }else{
            $ficaFrioAi= false;
            $LABELPRODUTOADQ = "%%";
        }
        $params = array(
            ':LABELPRODUTOADQ' => $LABELPRODUTOADQ,
            ':NRORG'       => $NRORG
        );
        $filial = $this->factory->getProdutosGer($params);
        return $filial;
    }
	
	public function getProdutos($params){
	    return $this->factory->getProdutos(array(
	        ":NRORG"        => $params["NRORG"],
	        ":NRPRODUTOADQ" => $params["NRPRODUTOADQ"],
	        ":TNRPTODUTOADQ"=> $params["TNRPTODUTOADQ"],
	        ":CDTIPORECE"   => $params["CDTIPORECE"],
	        ":TCDTIPORECE"  => $params["TCDTIPORECE"],
	        ":ALL_FIELDS"   => $params["ALL_FIELDS"],
	        ":TALL_FIELDS"  => $params["TALL_FIELDS"]
	    ));
	}
	
	public function getNovoCodigoTipoRece($row) {
	    return NovoCodigo::geraCodigo($this->conn, 'TPRECEPRODADQ', $row['NRORG']);
	}
	
	public function saveProduto($row) {
        if ($row['VRTOLERANCIA'] > 0.03)
            throw new \Exception('TOLERANCIA', 1);
        if($row['NMBANDEIRA'] == null){
            $row['NRBANDEIRAVAN'] = null;
        }
        if($row['NRDIASVENC'] === 0){
            throw new \Exception('INVALID_FORMAT', 3);
        }
        
        $params = array(
            ':VRTOLERANCIA'  =>  $row['VRTOLERANCIA'],
            ':DTULTATU'      =>  $row['DTULTATU'],
            ':NRORGULTATU'   =>  $row['NRORGULTATU'],
            ':CDOPERULTATU'  =>  $row['CDOPERULTATU'],
            ':NRORG'         =>  $row['NRORG'],
            ':IDATIVO'       =>  $row['IDATIVO'],
            ':NRPRODUTOADQ'  =>  $row['NRPRODUTOADQ'],
            ':CDPRODUTOADQ'  =>  $row['CDPRODUTOADQ'],
            ':NRBANDEIRAVAN' =>  $row['NRBANDEIRAVAN'],
            ':IDVISIVEL'     =>  $row['IDVISIVEL'],
            ':NRDIASVENC'    =>  $row['NRDIASVENC']
        );
        
        $this->factory->saveProduct($params);
	}
	
	public function saveAdquirente($row) {
	    if(is_numeric($row["VRTAXAADM"]) == false)
	        $row["VRTAXAADM"] = preg_replace('/[^.0-9]+/', '', $row["VRTAXAADM"]);
	    if(gettype(strpos($row['VRTAXAADM'], '-')) == 'integer')
	        throw new \Exception('INVALID_FORMAT', 1);
        if (($row['VRTAXAADM'] === '0')||(($row['NRDIASVENC']!='')&&($row['VRTAXAADM']=='')))
            throw new \Exception('INVALID_FORMAT', 1);
        if ($row['VRTAXAADM'] > 100)
            throw new \Exception('TAXA', 2);
        if ($row['NRDIASVENC'] === 0)
            throw new \Exception('INVALID_FORMAT', 3);
            
        if(($row['VRTAXAADM'] =='')&&($row['NRDIASVENC']=='')){
            $this->removeProdAdq($row);
            
        } else if (!($row['VRTAXAADM'] === '') && (strlen($row['VRTAXAADM']) < 10) || !($row['NRDIASVENC'] === '')){

            $params = array(
                ':NRADQUIRENTE' => $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
                ':NRORG'        => $row['NRORG'],
                ':IDATIVO'      => $row['IDATIVO']
            );
            $result = $this->factory->checkRowIsNotNull($params);
            if(isset($result[0])) {
                $row['NRTAXAADQPROD'] = $result[0]['NRTAXAADQPROD'];
                $params = array(
                    ':VRTAXAADM'    => $row['VRTAXAADM'],
                    ':DTULTATU'     => $row['DTULTATU'],
                    ':NRORGULTATU'  => $row['NRORGULTATU'],
                    ':CDOPERULTATU' => $row['CDOPERULTATU'],
                    ':NRORG'        => $row['NRORG'],
                    ':IDATIVO'      => $row['IDATIVO'],
                    ':NRADQUIRENTE' => $row['NRADQUIRENTE'],
                    ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
                    ':NRTAXAADQPROD'=> $row['NRTAXAADQPROD'],
                    ':VRTAXAADM'    => $row['VRTAXAADM'],
                    ':NRDIASVENC'   => $row['NRDIASVENC']
                );
        
                
                $this->factory->saveTypeUpdateAdq($params);
            } else {
                $row['NRTAXAADQPROD'] = intval($this->util->newCode('TAXAADQPROD', '10'));
                
                $params = array(
                    ':NRTAXAADQPROD' => $row['NRTAXAADQPROD'],
                    ':NRADQUIRENTE' => $row['NRADQUIRENTE'],
                    ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
                    ':VRTAXAADM'    => $row['VRTAXAADM'],
                    ':NRORG'        => $row['NRORG'],
                    ':IDATIVO'      => $row['IDATIVO'],
                    ':DTULTATU'     => $row['DTULTATU'],
                    ':NRORGULTATU'  => $row['NRORGULTATU'],
                    ':CDOPERULTATU' => $row['CDOPERULTATU'],
                    ':NRDIASVENC'   => $row['NRDIASVENC']
                );
                $this->factory->saveTypeInsertAdq($params);
            }
        }
        else {
            $this->removeProdAdq($row);
        }
            
        
        return $row['VRTAXAADM'];
	}
	
	public function removeProdAdq($row) {
	    $params = array(
	        ':NRADQUIRENTE' =>  $row['NRADQUIRENTE'],
            ':NRPRODUTOADQ' =>  $row['NRPRODUTOADQ'],
            ':NRORG'        =>  $row['NRORG'],
            ':IDATIVO'      =>  $row['IDATIVO']
	   );
	   
	   $result = $this->factory->getNrSequencialFromEstabelecToRemove($params);
	   if(isset($result[0])) {
    	   $row['NRTAXAADQPROD'] = $result[0]['NRTAXAADQPROD'];
            $params = array(
                ':NRORG'        =>  $row['NRORG'],
                ':IDATIVO'      =>  $row['IDATIVO'],
                ':NRTAXAADQPROD' =>  $row['NRTAXAADQPROD'],
                ':NRADQUIRENTE' =>  $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' =>  $row['NRPRODUTOADQ']
            );
            $this->factory->removeProdAdq($params);
	   }
	}
	
	public function saveEstabelec($row) {
	    if ($row['hasEstabelec'])
	        $this->validateEstabelec($row);
	    else
	        $row['NRESTABELEC'] = null;
        if($row["NRESTABELEC"] == "")
            $this->isTotalEstabelec($row);
        if(gettype(strpos($row['VRTAXAADM'], '-')) == 'integer')
	        throw new \Exception('INVALID_FORMAT', 1);
	        
		$row['VRTAXAADM'] = round($row['VRTAXAADM'], 5);
		
		if ($row['VRTAXAADM'] > 100)
            throw new \Exception('TAXA', 3);
        if ($row['VRTAXAADM'] == 0)
            throw new \Exception('TAXA_ZERO', 4);
            
        $row['NRTAXAADQPROD'] = intval($this->util->newCode('TAXAADQPROD', '10'));
            
        $params = array(
            ':NRADQUIRENTE' => $row['NRADQUIRENTE'],
            ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
        	':NRESTABELEC'  => $row['NRESTABELEC'],
            ':VRTAXAADM'    => $row['VRTAXAADM'],
            ':NRTAXAADQPROD'=> $row['NRTAXAADQPROD'],
            ':NRORG'        => $row['NRORG'],
            ':IDATIVO'      => $row['IDATIVO'],
            ':DTULTATU'     => $row['DTULTATU'],
            ':NRORGULTATU'  => $row['NRORGULTATU'],
            ':CDOPERULTATU' => $row['CDOPERULTATU']
        );
        $this->factory->saveEstabelec($params);
	}
	
	public function isTotalEstabelec($row) {
		$params = array(
			':NRADQUIRENTE' => $row['NRADQUIRENTE'],
            ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
			':NRORG'        => $row['NRORG'],
            ':IDATIVO'      => $row['IDATIVO']
		);
		$result = $this->factory->isTotalEstabelec($params);
		foreach ($result as $key => $value) {
		if ($value["LABELESTABELEC"] == "Todos")
			throw new \Exception('GERAL_ESTABELECIMENTO', 5);
		}	    
	}
	
	public function validateEstabelec($row) {
		$params = array(
			':NRESTABELEC'	=> $row['NRESTABELEC'],
			':NRADQUIRENTE' => $row['NRADQUIRENTE'],
            ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
			':NRORG'        => $row['NRORG'],
            ':IDATIVO'      => $row['IDATIVO']
		);
		$result = $this->factory->getEstabelecFromTaxaAdqProd($params);
		if (isset($result[0]))
			throw new \Exception('ESTABELECIMENTO', 2);
	}
	
	public function validateEstabelecEdit($row) {
		$params = array(
			':NRESTABELEC'	=> $row['NRESTABELEC'],
			':NRADQUIRENTE' => $row['NRADQUIRENTE'],
            ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
            ':NRTAXAADQPROD'=> $row['NRTAXAADQPROD'],
			':NRORG'        => $row['NRORG'],
            ':IDATIVO'      => $row['IDATIVO']
		);
		$result = $this->factory->getEstabelecFromTaxaAdqProdEdit($params);
		if (isset($result[0]))
			throw new \Exception('ESTABELECIMENTO', 4);
	}
	
	public function saveEditEstabelec($row) {
	    if(gettype(strpos($row['VRTAXAADM'], '-')) == 'integer')
	        throw new \Exception('INVALID_FORMAT', 1);
	    
		$row['VRTAXAADM'] = round($row['VRTAXAADM'], 5);
		
		if ($row['VRTAXAADM'] > 100)
            throw new \Exception('TAXA', 2);
        if ($row['VRTAXAADM'] == 0)
            throw new \Exception('TAXA_ZERO', 3);
	        $this->validateEstabelecEdit($row);
        if (isset($row['NRESTABELEC'])) {
            $params = array(
                ':NRESTABELEC'  => $row['NRESTABELEC'],
                ':VRTAXAADM'    => $row['VRTAXAADM'],
                ':NRTAXAADQPROD'=> $row['NRTAXAADQPROD'],
                ':NRADQUIRENTE' => $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
                ':NRORG'        => $row['NRORG'],
                ':IDATIVO'      => $row['IDATIVO'],
                ':DTULTATU'     => $row['DTULTATU'],
                ':NRORGULTATU'  => $row['NRORGULTATU'],
                ':CDOPERULTATU' => $row['CDOPERULTATU']
            );
            
            $this->factory->saveEditEstabelec($params);
        } else {
            $params = array(
    	        ':NRADQUIRENTE' =>  $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' =>  $row['NRPRODUTOADQ'],
                ':NRORG'        =>  $row['NRORG'],
                ':IDATIVO'      =>  $row['IDATIVO']
    	   );
            
            $result = $this->factory->getNrSequencialToRemove($params);
    	    $row['NRTAXAADQPROD'] = $result[0]['NRTAXAADQPROD'];

            $params = array(
                ':VRTAXAADM'    => $row['VRTAXAADM'],
                ':NRTAXAADQPROD'=> $row['NRTAXAADQPROD'],
                ':NRADQUIRENTE' => $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
                ':NRORG'        => $row['NRORG'],
                ':IDATIVO'      => $row['IDATIVO'],
                ':DTULTATU'     => $row['DTULTATU'],
                ':NRORGULTATU'  => $row['NRORGULTATU'],
                ':CDOPERULTATU' => $row['CDOPERULTATU']
            );
            
            $this->factory->saveEditEstabelecType2($params);
        }
        
	}
	
	public function removeEstabelec($row) {
	    if ($row['NRESTABELEC']) {
    	    $params = array(
    	        ':NRESTABELEC'  =>  $row['NRESTABELEC'],
    	        ':NRADQUIRENTE' =>  $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' =>  $row['NRPRODUTOADQ'],
                ':NRORG'        =>  $row['NRORG'],
                ':IDATIVO'      =>  $row['IDATIVO']
    	   );
    	   $result = $this->factory->getNrSequencialFromEstabelecToRemoveEst($params);
    	   $row['NRTAXAADQPROD'] = $result[0]['NRTAXAADQPROD'];
            
            $params = array(
                ':NRORG'        =>  $row['NRORG'],
                ':IDATIVO'      =>  $row['IDATIVO'],
                ':NRTAXAADQPROD'=>  $row['NRTAXAADQPROD'],
                ':NRADQUIRENTE' =>  $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' =>  $row['NRPRODUTOADQ'],
                ':NRESTABELEC'  =>  $row['NRESTABELEC']
            );
        
            $this->factory->removeEstabelec($params);
	    } else {
	        $params = array(
    	        ':NRADQUIRENTE' =>  $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' =>  $row['NRPRODUTOADQ'],
                ':NRORG'        =>  $row['NRORG'],
                ':IDATIVO'      =>  $row['IDATIVO']
    	   );
    	   
    	   $result = $this->factory->getNrSequencialToRemove($params);
    	   $row['NRTAXAADQPROD'] = $result[0]['NRTAXAADQPROD'];
    	   
    	   $params = array(
                ':NRORG'        =>  $row['NRORG'],
                ':IDATIVO'      =>  $row['IDATIVO'],
                ':NRTAXAADQPROD'=>  $row['NRTAXAADQPROD'],
                ':NRADQUIRENTE' =>  $row['NRADQUIRENTE'],
                ':NRPRODUTOADQ' =>  $row['NRPRODUTOADQ']
            );
        
            $this->factory->removeTaxaAdqProd($params);
	    }
	}

    public function getPeriodTaxa($params) {

        $NRPRODUTOADQ = $params[0]['value'];
        $NRADQUIRENTE = $params[1]['value'];

        $params = array(
            ':NRPRODUTOADQ' => $NRPRODUTOADQ,
            ':NRADQUIRENTE' => $NRADQUIRENTE
        );

        $standarts = $this->factory->getPeriodTaxa($params);
        return $standarts;
    }

    public function getPeriodTaxaRow($params) {

        $NRPRODUTOADQ = $params[0]['value'];
        $NRADQUIRENTE = $params[1]['value'];
        $NRTAXAPERADQ = $params[3]['value'];

        $params = array(
            ':NRPRODUTOADQ' => $NRPRODUTOADQ,
            ':NRADQUIRENTE' => $NRADQUIRENTE,
            ':NRTAXAPERADQ' => $NRTAXAPERADQ
        );
        $standarts = $this->factory->getPeriodTaxaRow($params);
        return $standarts;
    }

    public function alterarPeriodoTaxa ($params) {
        $NRPRODUTOADQ  = $params[0]['NRPRODUTOADQ'];
        $NRADQUIRENTE  = $params[0]['NRADQUIRENTE'];
        $NRTAXAPERADQ  = $params[0]['NRTAXAPERADQ'];
        $DTINICIAL     = $params[0]['DTINICIAL'];
        $DTFINAL       = $params[0]['DTFINAL'];
        $VRTAXAADM     = $params[0]['VRTAXAADM'];

        $paramInt = array(
            ':DTINICIAL'    => $DTINICIAL,
            ':DTFINAL'      => $DTFINAL,
            ':NRTAXAPERADQ' => $NRTAXAPERADQ,
            ':NRADQUIRENTE' => $NRADQUIRENTE,
            ':NRPRODUTOADQ' => $NRPRODUTOADQ
        );

        $verificaIntervalo =  $this->factory->verificaIntervaloAlterar($paramInt);
        if($verificaIntervalo[0]["QUANTIDADE"] == 0){
            $paramethers = array(
                ':NRPRODUTOADQ' => $NRPRODUTOADQ,
                ':NRADQUIRENTE' => $NRADQUIRENTE,
                ':NRTAXAPERADQ' => $NRTAXAPERADQ,
                ':DTINICIAL'    => $DTINICIAL,
                ':DTFINAL'      => $DTFINAL,
                ':VRTAXAADM'    => $VRTAXAADM
            );
            $standarts = $this->factory->alterarPeriodoTaxa($paramethers);
            return $standarts;            
        }else{
            throw new \Exception('Período informado coincide com algum período já cadastrado.', 10);
        }
    }

    public function inserirPeriodoTaxa ($params) {
        $NRPRODUTOADQ  = $params[0]['NRPRODUTOADQ'];
        $NRADQUIRENTE  = $params[0]['NRADQUIRENTE'];
        $DTINICIAL     = $params[0]['DTINICIAL'];
        $DTFINAL       = $params[0]['DTFINAL'];
        $VRTAXAADM     = $params[0]['VRTAXAADM'];

        $paramInt = array(
            ':DTINICIAL'    => $DTINICIAL,
            ':DTFINAL'      => $DTFINAL,
            ':NRPRODUTOADQ' => $NRPRODUTOADQ,
            ':NRADQUIRENTE' => $NRADQUIRENTE
        );
        
        $verificaIntervalo =  $this->factory->verificaIntervalo($paramInt);

        if($verificaIntervalo[0]["QUANTIDADE"] == 0){
        $NRTAXAPERADQ = $this->util->newCode('TAXAPERADQ', '10');
        $NRTAXAPERADQ = intval($NRTAXAPERADQ);
        $paramethers = array(
            ':NRPRODUTOADQ'  => $NRPRODUTOADQ,
            ':NRADQUIRENTE'  => $NRADQUIRENTE,
            ':NRTAXAPERADQ'  => $NRTAXAPERADQ,
            ':DTINICIAL'     => $DTINICIAL,
            ':DTFINAL'       => $DTFINAL,
            ':VRTAXAADM'     => $VRTAXAADM
        );
        $standarts = $this->factory->inserirPeriodoTaxa($paramethers);
        return $standarts;
        }else{
            throw new \Exception('Período informado coincide com algum período já cadastrado.', 12);
        }


    }

    public function deletarPeriodoTaxa ($params) {

        $params = array(
            ':NRPRODUTOADQ' => $params[0]["NRPRODUTOADQ"],
            ':NRADQUIRENTE' => $params[0]["NRADQUIRENTE"],
            ':NRTAXAPERADQ' => $params[0]["NRTAXAPERADQ"]
        );
        $standarts = $this->factory->deletarPeriodoTaxa($params);
        return $standarts;
    }
    
   	public function registerExists($row){
		$acquires = $this->factory->registerExists(array(
			':NRORG' => $row['NRORG'],
			':NRADQUIRENTE' => $row['NRADQUIRENTE'],
			':NRPRODUTOADQ' => $row['NRPRODUTOADQ'],
			':QTPARCELA'    => $row['QTPARCELA']
        ));
		return !empty($acquires);
	}
	
}